..  Copyright (C)  Stephen Schaub.  Permission is granted to copy, distribute
    and/or modify this document under the terms of the GNU Free Documentation
    License, Version 1.3 or any later version published by the Free Software
    Foundation; with Invariant Sections being Forward, Prefaces, and
    Contributor List, no Front-Cover Texts, and no Back-Cover Texts.  A copy of
    the license is included in the section entitled "GNU Free Documentation
    License".

Glossary
--------

.. glossary::

    assert statement
        A statement that verifies that a boolean condition is true.

    design by contract
        An approach to designing functions that specifies function behavior using
        preconditions and postconditions.

    postcondition
        Part of a function specification that states the work the function completed by the function if the precondition is
        satisfied.

    precondition
        A boolean condition that the caller of a function must ensure is true 
        in order for the function to produce correct results

    specification-based tests 
        tests that are designed based only on the information in the function specification, without considering any of
        the details in the function implementation.

    unit test
        Code that tests a function to determine if it works properly

